==> qtjambi-xml-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiXml/QDomCDATASection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomCDATASection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomCDATASection")
    QDomCDATASection *_ptr = reinterpret_cast<QDomCDATASection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomCDATASection()
void __qt_construct_QDomCDATASection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCDATASection()")
    Q_UNUSED(__java_arguments)
    QDomCDATASection *__qt_this = new(__qtjambi_ptr) QDomCDATASection();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomCDATASection::QDomCDATASection()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCDATASection_initialize_1native__Lio_qt_xml_QDomCDATASection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCDATASection::QDomCDATASection()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCDATASection, sizeof(QDomCDATASection), typeid(QDomCDATASection), 0, false, &deleter_QDomCDATASection, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomCDATASection(QDomCDATASection)
void __qt_construct_QDomCDATASection_cref_QDomCDATASection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCDATASection(QDomCDATASection)")
    jobject x0 = __java_arguments[0].l;
    const QDomCDATASection& __qt_x0 = qtjambi_cast<const QDomCDATASection&>(__jni_env, x0);
    QDomCDATASection *__qt_this = new(__qtjambi_ptr) QDomCDATASection(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomCDATASection::QDomCDATASection(QDomCDATASection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCDATASection_initialize_1native__Lio_qt_xml_QDomCDATASection_2Lio_qt_xml_QDomCDATASection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCDATASection::QDomCDATASection(QDomCDATASection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCDATASection_cref_QDomCDATASection, sizeof(QDomCDATASection), typeid(QDomCDATASection), 0, false, &deleter_QDomCDATASection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomCDATASection
void __qt_destruct_QDomCDATASection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomCDATASection")
    reinterpret_cast<QDomCDATASection*>(ptr)->~QDomCDATASection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomCDATASection::operator=(QDomCDATASection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCDATASection_assign_1native_1cref_1QDomCDATASection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCDATASection *__qt_this = QtJambiAPI::objectFromNativeId<QDomCDATASection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCDATASection::operator=(QDomCDATASection)", __this_nativeId)
        const QDomCDATASection& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomCDATASection>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCDATASection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomCDATASection *__qt_this = QtJambiAPI::objectFromNativeId<QDomCDATASection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomCDATASection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomCDATASection>("QDomCDATASection", "io/qt/xml/QDomCDATASection");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomCDATASection, {
        ConstructorInfo(&__qt_construct_QDomCDATASection, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomCDATASection_cref_QDomCDATASection, "Lio/qt/xml/QDomCDATASection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomCDATASection);
    registerMetaType<QDomCDATASection>("QDomCDATASection");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.8.3.jar: sources/QtJambiXml/QDomCDATASection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomCDATASection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomCDATASection")
    QDomCDATASection *_ptr = reinterpret_cast<QDomCDATASection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomCDATASection()
void __qt_construct_QDomCDATASection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCDATASection()")
    Q_UNUSED(__java_arguments)
    QDomCDATASection *__qt_this = new(__qtjambi_ptr) QDomCDATASection();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomCDATASection::QDomCDATASection()
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomCDATASection_initialize_1native__Lio_qt_xml_QDomCDATASection_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCDATASection::QDomCDATASection()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCDATASection, sizeof(QDomCDATASection), typeid(QDomCDATASection), 0, false, &deleter_QDomCDATASection, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomCDATASection(QDomCDATASection)
void __qt_construct_QDomCDATASection_cref_QDomCDATASection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCDATASection(QDomCDATASection)")
    jobject cdataSection0 = __java_arguments[0].l;
    const QDomCDATASection& __qt_cdataSection0 = qtjambi_cast<const QDomCDATASection&>(__jni_env, cdataSection0);
    QDomCDATASection *__qt_this = new(__qtjambi_ptr) QDomCDATASection(__qt_cdataSection0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomCDATASection::QDomCDATASection(QDomCDATASection)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomCDATASection_initialize_1native__Lio_qt_xml_QDomCDATASection_2Lio_qt_xml_QDomCDATASection_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject cdataSection0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCDATASection::QDomCDATASection(QDomCDATASection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = cdataSection0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCDATASection_cref_QDomCDATASection, sizeof(QDomCDATASection), typeid(QDomCDATASection), 0, false, &deleter_QDomCDATASection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomCDATASection
void __qt_destruct_QDomCDATASection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomCDATASection")
    reinterpret_cast<QDomCDATASection*>(ptr)->~QDomCDATASection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomCDATASection::operator=(QDomCDATASection)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomCDATASection_assign_1native_1cref_1QDomCDATASection__JJ
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCDATASection *__qt_this = QtJambiAPI::objectFromNativeId<QDomCDATASection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCDATASection::operator=(QDomCDATASection)", __this_nativeId)
        const QDomCDATASection& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDomCDATASection>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_xml_QDomCDATASection_clone_1native
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomCDATASection *__qt_this = QtJambiAPI::objectFromNativeId<QDomCDATASection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomCDATASection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomCDATASection>("QDomCDATASection", "io/qt/xml/QDomCDATASection");
    Q_UNUSED(typeId)
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomCDATASection, {
        ConstructorInfo{&__qt_construct_QDomCDATASection, nullptr}
       ,ConstructorInfo{&__qt_construct_QDomCDATASection_cref_QDomCDATASection, "Lio/qt/xml/QDomCDATASection;"}
    });
    registerDeleter(typeId, &deleter_QDomCDATASection);
    registerMetaType<QDomCDATASection>("QDomCDATASection");
}
